# Styling

We follow pep-8 formatting

# Docstrings
We follow the Google-style of doc strings. E.g.:

```
This is an example of Google style.

Args:
    param1: This is the first param.
    param2: This is a second param.

Returns:
    This is a description of what is returned.

Raises:
    KeyError: Raises an exception.
```